# Revision GCS Client

Google Cloud Storage client for [Revision](https://github.com/COLORFULBOARD/revision).

```javascript
{
  "clients": [
    {
      "key": "YOUR_KEY",
      "module": "revision_gcs.GCSClient",
      "dir_path": "PATH/TO/DATASET_DIR",
      "revision_file": "CHANGELOG.md",
      "options": {
        "key_file": "PATH/TO/KEY_FILE",
        "bucket_name": "YOUR_BUCKET_NAME"
      }
    }
  ]
}
```
